from distutils.core import setup

setup(
	name             = 'pentest',
	packages         = [ 'pentest' ],
	version          = '1.0.2',
	license          = 'gpl-2.0', # https://help.github.com/articles/licensing-a-repository
	description      = 'Pentesting helpers packages',
	author           = 'Drawcoders',
	author_email     = 'contacto@drawcoders.cl',
	url              = 'https://github.com/drawcoders/pentest-helpers/',
	download_url     = 'https://github.com/drawcoders/pentest-helpers/archive/master.zip',
	keywords         = ['security', 'utils', 'helpers', 'pentesting'],
	install_requires = [ ],
	classifiers      = [
		# 'Development Status :: 5 - Production/Stable',
		'Development Status :: 4 - Beta',
		'Intended Audience :: Developers',
		'Topic :: Software Development :: Build Tools',
		'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
		'Programming Language :: Python :: 3.6',
	]
)